*******************
vizual
*******************

overview
=============

vizual is Dorado's tool for creating visual resources for data capture, reduction, and analysis. vizual aims to create clean visually appealing graphics that are simple to implement, consistent in aesthetic, and viable for publication.

Reference/API
=============

.. automodapi:: dorado.imreduc